@@ -435,6 +435,64 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                                 ],
                                 "type": "object"
                             },
+                            "max_transfer_load": {
+                                "additionalProperties": false,
+                                "nullable": true,
+                                "properties": {
+                                    "capacity": {
+                                        "additionalProperties": false,
+                                        "nullable": true,
+                                        "properties": {
+                                            "capacity_x": {
+                                                "default": 0,
+                                                "format": "double",
+                                                "maximum": 1000000,
+                                                "minimum": 0,
+                                                "type": "number"
+                                            },
+                                            "capacity_y": {
+                                                "default": 0,
+                                                "format": "double",
+                                                "maximum": 1000000,
+                                                "minimum": 0,
+                                                "type": "number"
+                                            },
+                                            "capacity_z": {
+                                                "default": 0,
+                                                "format": "double",
+                                                "maximum": 1000000,
+                                                "minimum": 0,
+                                                "type": "number"
+                                            },
+                                            "mass": {
+                                                "default": 0,
+                                                "format": "double",
+                                                "maximum": 1000000,
+                                                "minimum": 0,
+                                                "type": "number"
+                                            },
+                                            "volume": {
+                                                "default": 0,
+                                                "format": "double",
+                                                "maximum": 1000000,
+                                                "minimum": 0,
+                                                "type": "number"
+                                            }
+                                        },
+                                        "type": "object"
+                                    },
+                                    "count": {
+                                        "format": "int32",
+                                        "minimum": 0,
+                                        "type": "integer"
+                                    }
+                                },
+                                "required": [
+                                    "count",
+                                    "capacity"
+                                ],
+                                "type": "object"
+                            },
                             "statistics": {
                                 "additionalProperties": false,
                                 "nullable": true,
@@ -1163,10 +1221,11 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                 "method": {
                     "enum": [
                         "PLAN",
+                        "REPLAN",
+                        "ACTUALIZE",
                         "CONVERT",
                         "ANALYTICS",
                         "PREDICT",
-                        "ACTUALIZE",
                         "VALIDATE",
                         "ROUTE",
                         "MATRIX",
